icenet.data.sic package
=======================

Submodules
----------

icenet.data.sic.mask module
---------------------------

.. automodule:: icenet.data.sic.mask
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.sic.osisaf module
-----------------------------

.. automodule:: icenet.data.sic.osisaf
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: icenet.data.sic
    :members:
    :undoc-members:
    :show-inheritance:
